Rucio Clients Examples — Rucio 1.12.2 documentation

# Rucio Clients Examples

Below are some examples of using Rucio’s Client class. We assume that there is a Rucio server running on the localhost on port 80/443.

## Service

### `ping`

Discover server version information.

            __init__
            '''
            self.cacert = config_get('test', 'cacert')
            self.usercert = config_get('test', 'usercert')
            try:

## Account

### `create_account`

Add an account.